monkey.mailman.sieppari

Interceptor implementation for Mailman that uses Sieppari as backing.

Interceptor implementation for Mailman that uses Sieppari as backing.
raw docstring

->interceptorclj

Converts its argument to an interceptor

Converts its argument to an interceptor
sourceraw docstring

executeclj

(execute interceptors ctx)
source

cljdoc builds & hosts documentation for Clojure/Script libraries